InvalidProofShapeError

Enum InvalidProofShapeError 

pub enum InvalidProofShapeError {
Show 19 variants InstanceCountMismatch, TraceLocalWidthMismatch { air: usize, expected: usize, got: usize, }, TraceNextMismatch { air: usize, }, UnexpectedTraceNext { air: usize, }, QuotientChunksCountMismatch { air: usize, expected: usize, got: usize, }, QuotientChunkDimensionMismatch { air: usize, }, QuotientDomainsCountMismatch { air: usize, }, PreprocessedTraceWidthMismatch { expected_local: usize, expected_next: usize, got_local: usize, got_next: usize, }, PreprocessedVerifierKeyInconsistency, PreprocessedDegreeMismatch { vk_degree_bits: usize, proof_degree_bits: usize, }, PreprocessedWidthMismatch { air: usize, }, UnexpectedPreprocessedValues { air: usize, }, DegreeBitsTooSmall { air: Option<usize>, minimum: usize, got: usize, }, DegreeBitsTooLarge { air: Option<usize>, maximum: usize, got: usize, }, QuotientDomainTooLarge { air: Option<usize>, maximum: usize, got: usize, }, MissingPreprocessedValues { air: usize, }, PreprocessedMetadataMismatch { air: usize, }, PublicValuesLengthMismatch { expected: usize, got: usize, }, OpenedValuesDimensionMismatch,
}
Specific reasons why a proof’s shape is invalid.

Variants



InstanceCountMismatch

Instance arrays (airs, opened_values, public_values, degree_bits) have different lengths.



TraceLocalWidthMismatch

Trace local width doesn’t match the AIR width.

Fields

air: usize
expected: usize
got: usize


TraceNextMismatch

Trace next values have wrong width or are unexpectedly missing.

Fields

air: usize


UnexpectedTraceNext

Trace next values present when AIR doesn’t use next row.

Fields

air: usize


QuotientChunksCountMismatch

Quotient chunks count doesn’t match expected.

Fields

air: usize
expected: usize
got: usize


QuotientChunkDimensionMismatch

Quotient chunk has wrong dimension.

Fields

air: usize


QuotientDomainsCountMismatch

Quotient opened values count doesn’t match domain count.

Fields

air: usize


PreprocessedTraceWidthMismatch

Preprocessed trace opened values width doesn’t match expected.

Fields

expected_local: usize
expected_next: usize
got_local: usize
got_next: usize


PreprocessedVerifierKeyInconsistency

Preprocessed verifier key is inconsistent with width.



PreprocessedDegreeMismatch

Preprocessed and main trace have different heights.

Fields

vk_degree_bits: usize
proof_degree_bits: usize


PreprocessedWidthMismatch

Preprocessed width mismatch for a specific AIR.

Fields

air: usize


UnexpectedPreprocessedValues

Preprocessed values present when preprocessed width is zero.

Fields

air: usize


DegreeBitsTooSmall

Proof degree bits are too small for the PCS ZK setting.

Fields

minimum: usize
got: usize


DegreeBitsTooLarge

Proof degree bits are too large to safely construct verifier domains.

Fields

maximum: usize
got: usize


QuotientDomainTooLarge

The quotient domain log-size overflows after adding degree bits and quotient chunk bits.

Fields

maximum: usize
got: usize


MissingPreprocessedValues

Missing preprocessed local or next values.

Fields

air: usize


PreprocessedMetadataMismatch

Preprocessed metadata missing or mismatched.

Fields

air: usize


PublicValuesLengthMismatch

Public values length doesn’t match what the AIR expects.

Fields

expected: usize
got: usize


OpenedValuesDimensionMismatch

Opened values (trace, quotient, random) don’t match expected dimensions.